regexutils

package
v2.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 13, 2026 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CheckRegexString

func CheckRegexString(candidateRegex string) error

CheckRegexString to make sure the string is a valid RE2 expression

func NewRegexWithProgramSize

func NewRegexWithProgramSize(candidateRegex string, programsize *uint32) *envoy_type_matcher_v3.RegexMatcher

NewRegexWithProgramSize creates a new regex matcher with the given program size. This means its tightly coupled to envoy's implementation of regex. NOTE: Call this after having checked regex with CheckRegexString.

Types

This section is empty.

Jump to